@@ -8,7 +8,7 @@ export OMP_NUM_THREADS=4
 export HDF5_USE_FILE_LOCKING="FALSE"
 
 gps_start_time=1272790000
-gps_end_time=1272790500
+gps_end_time=1272790512
 
 
 # test if there is a template bank. If not, make one
@@ -163,7 +163,8 @@ python -m mpi4py `which pycbc_live` \
 --ifar-upload-threshold 0.0001 \
 --round-start-time 4 \
 --start-time $gps_start_time \
---end-time $gps_end_time
+--end-time $gps_end_time \
+--verbose
 
 echo -e "\\n\\n>> [`date`] Checking results"
 ./check_results.py
