@@ -27,9 +27,9 @@ gravitational-wave detectors from public sources and/or dqsegdb.
 
 import json
 import numpy
-from astropy.utils.data import download_file
 from ligo.segments import segmentlist, segment
 from pycbc.frame.losc import get_run
+from pycbc.io import get_file
 
 
 def parse_veto_definer(veto_def_filename, ifos):
@@ -158,14 +158,14 @@ def query_flag(ifo, segment_name, start_time, end_time,
                                    ifo, segment_name,
                                    int(start_time), int(duration))
 
-            fname = download_file(url, cache=cache)
+            fname = get_file(url, cache=cache, timeout=10)
             data = json.load(open(fname, 'r'))
             if 'segments' in data:
                 flag_segments = data['segments']
 
         except Exception as e:
+            print(e)
             if source != 'any':
-                print(e)
                 raise ValueError("Unable to find {} segments in GWOSC, check "
                                  "flag name or times".format(segment_name))
             else:
