@@ -726,11 +726,12 @@ class LiveCoincTimeslideBackgroundEstimator(object):
     """Rolling buffer background estimation."""
 
     def __init__(self, num_templates, analysis_block, background_statistic,
-                 stat_files, ifos,
+                 sngl_ranking, stat_files, ifos,
                  ifar_limit=100,
                  timeslide_interval=.035,
                  coinc_threshold=.002,
-                 return_background=False):
+                 return_background=False,
+                 **kwargs):
         """
         Parameters
         ----------
@@ -740,6 +741,8 @@ class LiveCoincTimeslideBackgroundEstimator(object):
             The number of seconds in each analysis segment
         background_statistic: str
             The name of the statistic to rank coincident events.
+        sngl_ranking: str
+            The single detector ranking to use with the background statistic
         stat_files: list of strs
             List of filenames that contain information used to construct
             various coincident statistics.
@@ -757,13 +760,21 @@ class LiveCoincTimeslideBackgroundEstimator(object):
         return_background: boolean
             If true, background triggers will also be included in the file
             output.
+        kwargs: dict
+            Additional options for the statistic to use. See stat.py
+            for more details on statistic options.
         """
         from . import stat
         self.num_templates = num_templates
         self.analysis_block = analysis_block
 
         stat_class = stat.get_statistic(background_statistic)
-        self.stat_calculator = stat_class(stat_files, ifos)
+        self.stat_calculator = stat_class(
+            sngl_ranking,
+            stat_files,
+            ifos=ifos,
+            **kwargs
+        )
 
         self.timeslide_interval = timeslide_interval
         self.return_background = return_background
@@ -838,25 +849,35 @@ class LiveCoincTimeslideBackgroundEstimator(object):
 
     @classmethod
     def from_cli(cls, args, num_templates, analysis_chunk, ifos):
+        from . import stat
+        # Allow None inputs
+        if args.statistic_files is None:
+            args.statistic_files = []
+        if args.statistic_keywords is None:
+            args.statistic_keywords = []
+
+        # flatten the list of lists of filenames to a single list (may be empty)
+        args.statistic_files = sum(args.statistic_files, [])
+
+        kwargs = stat.parse_statistic_keywords_opt(args.statistic_keywords)
+
         return cls(num_templates, analysis_chunk,
-                   args.background_statistic,
-                   args.background_statistic_files,
+                   args.ranking_statistic,
+                   args.sngl_ranking,
+                   args.statistic_files,
                    return_background=args.store_background,
                    ifar_limit=args.background_ifar_limit,
                    timeslide_interval=args.timeslide_interval,
-                   ifos=ifos)
+                   ifos=ifos,
+                   **kwargs)
 
     @staticmethod
     def insert_args(parser):
         from . import stat
 
+        stat.insert_statistic_option_group(parser)
+
         group = parser.add_argument_group('Coincident Background Estimation')
-        group.add_argument('--background-statistic', default='newsnr',
-            choices=sorted(stat.statistic_dict.keys()),
-            help="Ranking statistic to use for candidate coincident events")
-        group.add_argument('--background-statistic-files', nargs='+',
-            help="Files containing precalculate values to calculate ranking"
-                 " statistic values", default=[])
         group.add_argument('--store-background', action='store_true',
             help="Return background triggers with zerolag coincidencs")
         group.add_argument('--background-ifar-limit', type=float,
@@ -1022,8 +1043,15 @@ class LiveCoincTimeslideBackgroundEstimator(object):
                                  self.time_window,
                                  self.timeslide_interval)
                 trig_stat = numpy.resize(trig_stat, len(i1))
-                c = self.stat_calculator.coinc(stats[i1], trig_stat,
-                                               slide, self.timeslide_interval)
+                sngls_list = [[ifo, trig_stat],
+                              [oifo, stats[i1]]]
+                # This can only use 2-det coincs at present
+                c = self.stat_calculator.rank_stat_coinc(
+                    sngls_list,
+                    slide,
+                    self.timeslide_interval,
+                    [0, -1]
+                )
                 offsets.append(slide)
                 cstat.append(c)
                 ctimes[oifo].append(times[i1])
