@@ -25,6 +25,7 @@ from .analytic import (TestEggbox, TestNormal, TestRosenbrock, TestVolcano,
 from .gaussian_noise import GaussianNoise
 from .marginalized_gaussian_noise import MarginalizedPhaseGaussianNoise
 from .marginalized_gaussian_noise import MarginalizedPolarization
+from .marginalized_gaussian_noise import MarginalizedHMPolPhase
 from .brute_marg import BruteParallelGaussianMarginalize
 from .single_template import SingleTemplate
 from .relbin import Relative
@@ -185,6 +186,7 @@ models = {_cls.name: _cls for _cls in (
     GaussianNoise,
     MarginalizedPhaseGaussianNoise,
     MarginalizedPolarization,
+    MarginalizedHMPolPhase,
     BruteParallelGaussianMarginalize,
     SingleTemplate,
     Relative
